@@ -9,14 +9,10 @@ import publication
 
 from jsii.python import classproperty
 
-import aws_cdk.aws_autoscaling_api
 import aws_cdk.aws_cloudwatch
 import aws_cdk.aws_events
 import aws_cdk.aws_iam
-import aws_cdk.aws_lambda
-import aws_cdk.aws_s3_notifications
-import aws_cdk.aws_sqs
-import aws_cdk.cdk
+import aws_cdk.core
 __all__ = []
 
 publication.publish()
